import type { ServiceFullInfo, ServiceInfo } from '../types';
/**
 * Returns basic info for specific Usercentrics service, or null if not found.
 *
 * The typing is *not complete* and contains only the info used internally:
 *
 * - `id` of the service, autogenerated by Usercentrics
 * - `name` of the service, configured in the admin interface
 * - `consent.status` of the service
 *
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=getservicesbaseinfo
 */
export declare const useServiceInfo: (serviceId: string) => ServiceInfo | null;
/**
 * Returns full info for specific Usercentrics service, or null if not found.
 * This triggers an extra API call and also returns `null` while loading.
 *
 * The typing is *not complete* and contains only the info used internally:
 *
 * - `id` of the service, autogenerated by Usercentrics
 * - `name` of the service, configured in the admin interface
 * - `consent.status` of the service
 * - `description` text of the service
 *
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=getservicesfullinfo
 */
export declare const useServiceFullInfo: (serviceId: string) => ServiceFullInfo | null;
