import type { ConsentType, ServiceFullInfo, ServiceInfo } from './types';
/**
 * Programmatic way to show First Layer.
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=showfirstlayer
 */
export declare const showFirstLayer: () => void;
/**
 * Programmatic way to show Second Layer. If a service/vendor Id value is passed,
 * Second Layer will open the right tab, scroll to the given service/vendor entry and expand it.
 * If no Id is passed, Second Layer will be shown without srcolling to any specific service/vendor.
 *
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=showsecondlayer
 */
export declare const showSecondLayer: (serviceId?: string) => void;
/**
 * A method to get array of all services with their basic information
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=getservicesbaseinfo
 */
export declare const getServicesBaseInfo: () => ServiceInfo[];
/**
 * A method to get array of all services with their full information.
 * An extra api request will be made, therefore the return represents
 * the eventual completion (or failure) of an asynchronous operation
 * and its returning value.
 *
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=getservicesfullinfo
 */
export declare const getServicesFullInfo: () => Promise<ServiceFullInfo[]>;
/** Returns true if Usercentrics service has been given consent */
export declare const hasServiceConsent: (service: ServiceInfo | null) => boolean;
/**
 * A method for accepting a single service.
 * @see https://docs.usercentrics.com/#/cmp-v2-ui-api?id=acceptservice
 */
export declare const acceptService: (serviceId: string, consentType?: ConsentType) => Promise<void>;
